//                                               -*- C++ -*-
/**
 *  @file  t_BasisSequence_std.cxx
 *  @brief The test file of class BasisSequence for standard methods
 *
 *  (C) Copyright 2005-2012 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: schueller $
 *  @date:   $LastChangedDate: 2010-02-04 16:44:49 +0100 (Thu, 04 Feb 2010) $
 *  Id:      $Id: t_BasisSequence_std.cxx 1473 2010-02-04 15:44:49Z dutka $
 */
#include <iostream>
#include "OT.hxx"
#include "OTtestcode.hxx"
#include "OStream.hxx"

using namespace OT;
using namespace OT::Test;

int main(int argc, char *argv[])
{
  TESTPREAMBLE;
  OStream fullprint(std::cout);
  const UnsignedLong dimension = 3;
  Description input;
  Description output[dimension];
  for ( UnsignedLong j = 0; j < dimension; ++ j )
    {
      OSS oss;
      oss << "x" << j;
      String in(oss);
      input.add(in);
      output[j].add(in);
    }
  Collection<NumericalMathFunction> coll;
  Indices cumulBasis;
  Indices partialBasis[dimension];
  for ( UnsignedLong j = 0; j < dimension; ++ j )
    {
      NumericalMathFunction ei(input, output[j], output[j]);
      coll.add(ei);
      cumulBasis.add(j);
      partialBasis[j] = cumulBasis;
    }

  Basis masterBasis(coll);
  BasisSequence seq(masterBasis);
  for ( UnsignedLong j = 0; j < dimension; ++ j )
    {
      seq.add(partialBasis[j]);
    }
  fullprint << "sequence = " << seq << std::endl;
  for ( UnsignedLong j = 0; j < dimension; ++ j )
    {
      fullprint << "indices of subBasis["<<j<<"] = "<< seq[j] << std::endl;
    }



  Study myStudy;
  myStudy.setStorageManager(XMLStorageManager("testStudy.ot"));
  myStudy.add("seq", seq);
  myStudy.save();

  Study myStudy2;
  myStudy2.setStorageManager(XMLStorageManager("testStudy.ot"));
  myStudy2.load();
  BasisSequence basisSequence;
  myStudy2.fillObject("seq", basisSequence);
  fullprint << "loaded BasisSequence=" << basisSequence << std::endl;



  return ExitCode::Success;
}
