//                                               -*- C++ -*-
/**
 * @file  t_ComputedNumericalMathEvaluationImplementation_copy.cxx
 * @brief The test file of class ComputedNumericalMathEvaluationImplementation when copying
 *
 *  (C) Copyright 2005-2012 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: schueller $
 *  @date:   $LastChangedDate: 2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012) $
 *  Id:      $Id: t_ComputedNumericalMathEvaluationImplementation_copy.cxx 2392 2012-02-17 18:35:43Z schueller $
 */

#include <iostream>
#include <sstream>
#include <exception>
#include "OT.hxx"
#include "OTtestcode.hxx"
#include "OStream.hxx"
#include "ComputedNumericalMathEvaluationImplementation.hxx"
#include "Exception.hxx"

using namespace OT;
using namespace OT::Test;

int main(int argc, char *argv[])
{
  TESTPREAMBLE;
  OStream fullprint(std::cout);

  try {

    try {
      // Test function operator ()
      // ComputedNumericalMathEvaluationImplementation myFunction("wrapper");
      ComputedNumericalMathEvaluationImplementation myFunctionImpl = ComputedNumericalMathEvaluationImplementation( "wrapper", WrapperFile::FindWrapperByName( "wrapper" ) );
      NumericalPoint inPoint1(2);
      inPoint1[0] = 10;
      inPoint1[1] = 10;
      NumericalPoint outPoint1 = myFunctionImpl( inPoint1 );
      fullprint << myFunctionImpl.getName() << "( " << inPoint1 << " ) = " << outPoint1 << std::endl;


      // Now we copy the object
      const ComputedNumericalMathEvaluationImplementation & ref_myFunctionImpl = myFunctionImpl;
      ComputedNumericalMathEvaluationImplementation newFunctionImpl(ref_myFunctionImpl);
      NumericalPoint inPoint2(2);
      inPoint2[0] = 100;
      inPoint2[1] = 100;
      NumericalPoint outPoint2 = newFunctionImpl( inPoint2 );
      fullprint << newFunctionImpl.getName() << "( " << inPoint2 << " ) = " << outPoint2 << std::endl;
    }
    catch (NoWrapperFileFoundException & ex) {
      throw TestFailed(ex.__repr__());
    }


  }
  catch (TestFailed & ex) {
    std::cerr << ex << std::endl;
    return ExitCode::Error;
  }

  return ExitCode::Success;
}
